netapp_ontap.models.subject_alternate_name API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.subject_alternate_name`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SubjectAlternateNameSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SubjectAlternateName object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `dns GET POST`

    A list of DNS names for Subject Alternate name extension.

  `email GET POST`

    A list of email addresses for Subject Alternate name extension

  `ip GET POST`

    A list of IP addresses for Subject Alternate name extension.

  `uri GET POST`

    A list of URIs for Subject Alternate name extension.